@@ -19,9 +19,16 @@ class FunctionRegressor(BaseEstimator, RegressorMixin):
 
     def fit(self, X, y):
         """
-        Fit the classifier.
+        Fit the classifier. No-Op.
+        """
+        # Run it to confirm no error happened.
+        _ = self.func(X, **self.kwargs)
+        self.fitted_ = True
+        return self
 
-        This classifier tries to confirm if the passed function can predict appropriate values on the train set.
+    def partial_fit(self, X, y=None):
+        """
+        Fit the classifier partially. No-Op.
         """
         # Run it to confirm no error happened.
         _ = self.func(X, **self.kwargs)
